Get the version of a package installed in the local R distribution
Source:R/utils2.R
GetPackageVersion.RdGet the version of a package installed in the local R distribution
R/utils2.R
GetPackageVersion.RdGet the version of a package installed in the local R distribution