Get the last validated step before current position.
Source:R/general_core_funcs.R
InitializeHistory.RdThis function returns the indice of the last validated step before the current step.
R/general_core_funcs.R
InitializeHistory.RdThis function returns the indice of the last validated step before the current step.