Skip to contents

Enables/disables the buttons 'Next step' and 'Previous step' wrt the current position of the cursor in the timeline.

Usage

ToggleState_NavBtns(current.pos, nSteps)

Arguments

current.pos

An `integer` which gives the current position of the cursor in the corresponding timeline

nSteps

The number of steps in the timeline

Value

NA

Examples

NULL
#> NULL