Skip to contents

Update the status of steps in a pipeline nor process.

Usage

UpdateStepsStatus(dataIn, config)

Arguments

dataIn

An instance of the `SummarizedExperiment` class

config

An instance of the `Config` class

Value

A vector of boolean in which each item indicates the status (VALIDATED, UNDONE, SKIPPED) of the corresponding step.

Examples

NULL
#> NULL