Checks if a package is available to load it
Checks if a package is available to load it
Examples
NULL
#> NULL
# \donttest{
pkgs.require(c("stats"))
#> [[1]]
#> NULL
#>
# }
Checks if a package is available to load it
Checks if a package is available to load it
NULL
#> NULL
# \donttest{
pkgs.require(c("stats"))
#> [[1]]
#> NULL
#>
# }