Discover Skipped Steps
Value
A vector of integers of the same length as steps.status and where skipped steps are identified with '-1'
Examples
steps <- c(1, 1, 0, 1)
Discover_Skipped_Steps(steps)
#> [1] 1 1 -1 1
Discover Skipped Steps
A vector of integers of the same length as steps.status and where skipped steps are identified with '-1'
steps <- c(1, 1, 0, 1)
Discover_Skipped_Steps(steps)
#> [1] 1 1 -1 1