This function returns the indice of the last validated step among all the steps
Examples
GetMaxValidated_AllSteps(c(1,1,0,1,0,0))
#> [1] 4
This function returns the indice of the last validated step among all the steps
GetMaxValidated_AllSteps(c(1,1,0,1,0,0))
#> [1] 4