Get the position of the last validated item
Usage
SetCurrentPosition(stepsstatus)
Arguments
- stepsstatus
A vector of integers which reflects the status of the steps
in the pipeline. Thus, the length of this vector is equal to the number of
steps
Examples
status <- c(1,1,1,0,0)
SetCurrentPosition(status)
#> [1] 3
status <- c(1,1,0,1, 0)
SetCurrentPosition(status)
#> [1] 4