Update the status enabled/disabled of the steps of a pipeline/process
Source:R/general_core_funcs.R
Update_State_Screens.RdUpdate the status enabled/disabled of the steps of a pipeline/process
Arguments
- is.skipped
A `boolean` indicating whether the current step of a process or process of a pipeline has the status SKIPPED
- is.enabled
A `boolean` indicating whether the current step of a process or process of a pipeline is enabled (TRUE) or not (FALSE)
- rv
A `list()` containing at least an item named 'steps.status' which is a vector of of names for the steps of a pipeline nor a process.