Read the value of a directoryInput
Usage
readDirectoryInput(session, inputId)
Arguments
- session
The session object passed to function given to shinyServer.
- inputId
The id of the input object
Details
Reads the value of the text field associated with a directoryInput
object that stores the user selected directory path.