This function goes into the 'R' directory of the file structure of a pipeline and load into memory the source code of the R scripts (which contains the interfaces of the process)
Examples
path <- system.file("workflow/PipelineDemo", package = "MagellanNTK")
source_wf_files(path)
#> [1] TRUE